@@ -2,61 +2,111 @@ import numpy as np
 import re
 import logging
 import networkx as nx
-from typing import Union
+from collections.abc import MutableMapping
 from kgcnn.graph.serial import get_preprocessor
-from copy import deepcopy
+from typing import Any, Union
+from copy import deepcopy, copy
 
 logging.basicConfig()  # Module logger
 module_logger = logging.getLogger(__name__)
 module_logger.setLevel(logging.INFO)
 
 
+# Base classes are collections.UserDict or collections.abc.MutableMapping. However, this comes with more
+# code to replicate dict-behaviour. Here GraphDict inherits from dict. Checking for numpy arrays can be disabled
+# in class variable. Set item is completely free.
 class GraphDict(dict):
     r"""Dictionary container to store graph information in tensor-form.
 
-    At the moment only numpy-arrays are supported. The naming convention is not restricted.
+    The tensors must be stored as numpy arrays. The naming convention is not restricted.
     The class is supposed to be handled just as a python dictionary.
+
     In addition, :obj:`assign_property` and :obj:`obtain_property` handles `None` values and cast into tensor format,
     when assigning a named value.
 
     Graph operations that modify edges or sort indices can be applied via :obj:`apply_preprocessor` located in
     :obj:`kgcnn.graph.preprocessor`.
 
-
     .. code-block:: python
 
         import numpy as np
         from kgcnn.graph.base import GraphDict
-        g = GraphDict({"edge_indices": np.array([[1, 0], [0, 1]]), "edge_labels": np.array([[-1], [1]])})
-        graph.set("graph_labels", [0])  # use set(), get() to assign (tensor) properties
+        graph = GraphDict({"edge_indices": np.array([[1, 0], [0, 1]]), "edge_labels": np.array([[-1], [1]])})
+        graph.set("graph_labels", [0])  # opposite is get()
         graph.set("edge_attributes", [[1.0], [2.0]])
-        g.apply_preprocessor("add_edge_self_loops")
-        g.apply_preprocessor("sort_edge_indices")
-        print(g)
+        graph.apply_preprocessor("add_edge_self_loops")
+        graph.apply_preprocessor("sort_edge_indices")
+        print(graph)
+
     """
 
-    # Implementation details: Inherits from python-dict at the moment but can be changed if this causes problems,
-    # alternatives would be: collections.UserDict or collections.abc.MutableMapping
-    # Also __setitem__ and update have not been altered in this version.
-    _tensor_conversion = np.array
+    _require_str_key = True
+    _cast_to_array = True
     _tensor_class = np.ndarray
+    _tensor_conversion = np.array
+    _require_validate = True
 
-    def __init__(self, sub_dict: dict = None):
-        r"""Initialize a new :obj:`GraphDict` instance.
+    def __init__(self, *args, **kwargs):
+        r"""Initialize a new :obj:`GraphDict` instance."""
+        super(GraphDict, self).__init__(*args, **kwargs)
+        if self._require_validate:
+            self.validate()
+        
+    def update(self, *args, **kwargs):
+        super(GraphDict, self).update(*args, **kwargs)
+        if self._require_validate:
+            self.validate()
+
+    def assign_property(self, key: str, value):
+        r"""Add a named property as key, value pair to self. If the value is `None`, nothing is done.
+        Similar to assign-item default method :obj:`__setitem__`, but ignores `None` values and casts to tensor.
 
         Args:
-            sub_dict: Dictionary or key-value pair of numpy arrays.
+            key (str): Name of the graph tensor to add to self.
+            value: Array or tensor value to add. Can also be None.
+
+        Returns:
+            None.
         """
-        if sub_dict is None:
-            sub_dict = {}
-        elif isinstance(sub_dict, (dict, list)):
-            in_dict = dict(sub_dict)
-            sub_dict = {key: value if isinstance(value, self._tensor_class) else self._tensor_conversion(value) for
-                        key, value in in_dict.items()}
-        elif isinstance(sub_dict, GraphDict):
-            sub_dict = {key: value if isinstance(value, self._tensor_class) else self._tensor_conversion(value) for
-                        key, value in sub_dict.items()}
-        super(GraphDict, self).__init__(sub_dict)
+        if self._require_str_key:
+            if not isinstance(key, str):
+                raise ValueError("`GraphDict` requires string keys, but kot '%s'." % key)
+        if value is not None:
+            if self._cast_to_array:
+                if not isinstance(value, self._tensor_class):
+                    value = self._tensor_conversion(value)
+            self[key] = value
+
+    def obtain_property(self, key: str):
+        """Get tensor item by name. If key is not found, `None` is returned.
+
+        Args:
+            key (str): Name of the key to get value for.
+
+        Returns:
+            self[key].
+        """
+        if key in self:
+            return self[key]
+        return None
+
+    def validate(self):
+        """Routine to check if items are set correctly, i.e. string key and np.ndarray values.
+        Could be done manually."""
+        for key, value in self.items():
+            if self._require_str_key:
+                if not isinstance(key, str):
+                    raise ValueError("`GraphDict` requires string keys, but kot '%s'." % key)
+            if self._cast_to_array:
+                if not isinstance(value, self._tensor_class):
+                    self[key] = self._tensor_conversion(value)
+
+    # Alias of internal assign_property and obtain property.
+    set = assign_property
+    # get = obtain_property
+
+    def copy(self):
+        return GraphDict({key: copy(value) for key, value in self.items()})
 
     def to_dict(self) -> dict:
         """Returns a python-dictionary of self. Does not copy values.
@@ -66,7 +116,64 @@ class GraphDict(dict):
         """
         return {key: value for key, value in self.items()}
 
-    def from_networkx(self, graph,
+    def search_properties(self, keys: Union[str, list]) -> list:
+        r"""Search for properties in self.
+
+        This includes a list of possible names or a pattern-matching of a single string.
+
+        Args:
+            keys (str, list): Pattern matching string or list of strings to search for.
+
+        Returns:
+            list: List of names in self that match :obj:`keys`.
+        """
+        if keys is None:
+            return []
+        elif isinstance(keys, str):
+            match_props = []
+            for x in self:
+                if re.match(keys, x):
+                    if re.match(keys, x).group() == x:
+                        match_props.append(x)
+            return sorted(match_props)
+        elif isinstance(keys, (list, tuple)):
+            # No pattern matching for list input.
+            return sorted([x for x in keys if x in self])
+        return []
+
+    # Old Alias
+    find_graph_properties = search_properties
+
+    def assert_has_valid_key(self, key: str, raise_error: bool = True) -> bool:
+        """Assert the property is found in self.
+
+        Args:
+            key (str): Name of property that must be defined.
+            raise_error (bool): Whether to raise error. Default is True.
+
+        Returns:
+            bool: Key is valid. Only if `raise_error` is False.
+        """
+        if key not in self or self.obtain_property(key) is None:
+            if raise_error:
+                raise AssertionError("`GraphDict` does not have '%s' key." % key)
+            return False
+        return True
+
+    def has_valid_key(self, key: str) -> bool:
+        """Check if the property is found in self and also is not Noe.
+
+        Args:
+            key (str): Name of property that must be defined.
+
+        Returns:
+            bool: Key is valid. Only if `raise_error` is False.
+        """
+        if key not in self or self.obtain_property(key) is None:
+            return False
+        return True
+
+    def from_networkx(self, graph: nx.Graph,
                       node_number: str = "node_number",
                       edge_indices: str = "edge_indices",
                       node_attributes: str = None,
@@ -126,12 +233,12 @@ class GraphDict(dict):
                 edges_attr_dict[d][i] = x[2][d]
 
         # Storing graph tensors in self.
-        self.assign_property(node_number, self._tensor_conversion(nodes_id))
-        self.assign_property(edge_indices, self._tensor_conversion(edge_id))
+        self.assign_property(node_number, nodes_id)
+        self.assign_property(edge_indices, edge_id)
         for key, value in node_attr_dict.items():
-            self.assign_property(key, self._tensor_conversion(value))
+            self.assign_property(key, value)
         for key, value in edges_attr_dict.items():
-            self.assign_property(key, self._tensor_conversion(value))
+            self.assign_property(key, value)
         return self
 
     def to_networkx(self, edge_indices: str = "edge_indices"):
@@ -147,95 +254,6 @@ class GraphDict(dict):
         graph.add_edges_from(self.obtain_property(edge_indices))
         return graph
 
-    def assign_property(self, key: str, value):
-        r"""Add a named property as key, value pair to self. If the value is `None`, nothing is done.
-        Similar to assign-item default method :obj:`__setitem__`, but ignores `None` values and casts to tensor.
-
-        Args:
-            key (str): Name of the graph tensor to add to self.
-            value: Array or tensor value to add. Can also be None.
-
-        Returns:
-            None.
-        """
-        if value is not None:
-            self.update({key: self._tensor_conversion(value)})
-
-    def obtain_property(self, key: str):
-        """Get tensor item by name. If key is not found, `None` is returned.
-
-        Args:
-            key (str): Name of the key to get value for.
-
-        Returns:
-            self[key].
-        """
-        if key in self:
-            return self[key]
-        return None
-
-    def search_properties(self, keys: Union[str, list]) -> list:
-        r"""Search for properties in self.
-
-        This includes a list of possible names or a pattern-matching of a single string.
-
-        Args:
-            keys (str, list): Pattern matching string or list of strings to search for.
-
-        Returns:
-            list: List of names in self that match :obj:`keys`.
-        """
-        if keys is None:
-            return []
-        elif isinstance(keys, str):
-            match_props = []
-            for x in self:
-                if re.match(keys, x):
-                    if re.match(keys, x).group() == x:
-                        match_props.append(x)
-            return sorted(match_props)
-        elif isinstance(keys, (list, tuple)):
-            # No pattern matching for list input.
-            return sorted([x for x in keys if x in self])
-        return []
-
-    # Old Alias
-    find_graph_properties = search_properties
-
-    def assert_has_valid_key(self, key: str, raise_error: bool = True):
-        """Assert the property is found in self.
-
-        Args:
-            key (str): Name of property that must be defined.
-            raise_error (bool): Whether to raise error. Default is True.
-
-        Returns:
-            bool: Key is valid. Only if `raise_error` is False.
-        """
-        if key not in self or self.obtain_property(key) is None:
-            if raise_error:
-                raise AssertionError("`GraphDict` does not have %s." % key)
-            return False
-        return True
-
-    def has_valid_key(self, key: str):
-        """Check if the property is found in self and also is not Noe.
-
-        Args:
-            key (str): Name of property that must be defined.
-
-        Returns:
-            bool: Key is valid. Only if `raise_error` is False.
-        """
-        if key not in self or self.obtain_property(key) is None:
-            return False
-        return True
-
-    # Alias of internal assign and obtain property.
-    set = assign_property
-
-    # get = obtain_property  # Already has correct behaviour.
-
     def apply_preprocessor(self, name, **kwargs):
         r"""Apply a preprocessor on self.
 
@@ -250,6 +268,7 @@ class GraphDict(dict):
         """
         if isinstance(name, str):
             proc_graph = get_preprocessor(name, **kwargs)(self)
+            # print(proc_graph)
             self.update(proc_graph)
             return self
         elif isinstance(name, GraphPreProcessorBase):
@@ -336,7 +355,7 @@ class GraphProcessorBase:
 
     @staticmethod
     def _assign_properties(graph: GraphDict, graph_properties: Union[list, np.ndarray],
-                           to_assign, to_search, in_place=False) -> dict:
+                           to_assign, to_search, in_place=False) -> Union[dict, GraphDict]:
         r"""Assign a list of arrays to a :obj:`GraphDict` by name.
 
         Args:
@@ -464,6 +483,7 @@ class GraphPreProcessorBase(GraphProcessorBase):
         # print(graph_properties)
         processed_properties = self.call(**graph_properties, **self._call_kwargs)
         out_graph = self._assign_properties(graph, processed_properties, self._to_assign, self._search)
+        # print(out_graph)
         if self._in_place:
             graph.update(out_graph)
             return graph
