@@ -135,9 +135,9 @@ class wACSFRad(GraphBaseLayer):
         self.pool_sum = PoolingLocalEdges(pooling_method="sum")
 
         # We can do this in init since weights do not depend on input shape.
-        self.param_initializer = param_initializer
-        self.param_regularizer = param_regularizer
-        self.param_constraint = param_constraint
+        self.param_initializer = ks.initializers.deserialize(param_initializer)
+        self.param_regularizer = ks.regularizers.deserialize(param_regularizer)
+        self.param_constraint = ks.constraints.deserialize(param_constraint)
         np_eta_mu = np.array(eta_mu)
         weight_shape = np_eta_mu.shape
         self._weight_eta_mu = self.add_weight(
@@ -169,7 +169,7 @@ class wACSFRad(GraphBaseLayer):
     def build(self, input_shape):
         super(wACSFRad, self).build(input_shape)
 
-    def call(self, inputs, **kwargs):
+    def call(self, inputs, mask=None, **kwargs):
         r"""Forward pass.
 
         Args:
@@ -180,14 +180,16 @@ class wACSFRad(GraphBaseLayer):
                 - ij (tf.RaggedTensor): Edge indices referring to nodes of shape (batch, [M], 2)
                 - w (tf.RaggedTensor): Edge weight tensor of shape (batch, [M], 1)
 
+            mask: Boolean mask for inputs. Not used. Defaults to None.
+
         Returns:
             tf.RaggedTensor: Atomic representation of shape `(batch, None, units)` .
         """
         if self.use_external_weights:
-            z, xyz, eij, w = inputs
+            z, xyz, eij, w = self.assert_ragged_input_rank(inputs, mask=mask, ragged_rank=1)
             z = self.map_values(tf.cast, z, dtype=eij.dtype)
         else:
-            z, xyz, eij = inputs
+            z, xyz, eij = self.assert_ragged_input_rank(inputs, mask=mask, ragged_rank=1)
             z = self.map_values(tf.cast, z, dtype=eij.dtype)
             zj = self.layer_gather_out([z, eij], **kwargs)
             w = self.layer_exp_dims(zj, **kwargs)
@@ -204,9 +206,9 @@ class wACSFRad(GraphBaseLayer):
         config = super(wACSFRad, self).get_config()
         config.update({"eta_mu": self.eta_mu, "cutoff": self.cutoff, "use_external_weights": self.use_external_weights,
                        "add_eps": self.add_eps,
-                       "param_constraint": self.param_constraint,
-                       "param_regularizer": self.param_regularizer,
-                       "param_initializer": self.param_initializer
+                       "param_constraint": ks.constraints.serialize(self.param_constraint),
+                       "param_regularizer": ks.regularizers.serialize(self.param_regularizer),
+                       "param_initializer": ks.initializers.serialize(self.param_initializer)
                        })
         return config
 
@@ -216,7 +218,7 @@ class wACSFAng(GraphBaseLayer):
     r"""Weighted atom-centered symmetry functions (wACSF) for high-dimensional neural network potentials (HDNNPs).
     From `Gastegger et al. (2017) <https://arxiv.org/abs/1712.05861>`_ .
     Default values can be found in `<https://aip.scitation.org/doi/suppl/10.1063/1.5019667>`_ .
-    This layer implements the radial part :math:`W_{i}^{ang}` :
+    This layer implements the angular part :math:`W_{i}^{ang}` :
 
     .. math::
 
@@ -257,9 +259,9 @@ class wACSFAng(GraphBaseLayer):
         self.layer_gather_2 = GatherNodesSelection(selection_index=2)
         self.layer_exp_dims = ExpandDims(axis=2)
         # We can do this in init since weights do not depend on input shape.
-        self.param_initializer = param_initializer
-        self.param_regularizer = param_regularizer
-        self.param_constraint = param_constraint
+        self.param_initializer = ks.initializers.deserialize(param_initializer)
+        self.param_regularizer = ks.regularizers.deserialize(param_regularizer)
+        self.param_constraint = ks.constraints.deserialize(param_constraint)
         np_eta_mu_lambda_zeta = np.array(eta_mu_lambda_zeta)
         weight_shape = np_eta_mu_lambda_zeta.shape
         self._weight_eta_mu_lambda_zeta = self.add_weight(
@@ -306,26 +308,28 @@ class wACSFAng(GraphBaseLayer):
     def build(self, input_shape):
         super(wACSFAng, self).build(input_shape)
 
-    def call(self, inputs, **kwargs):
+    def call(self, inputs, mask=None, **kwargs):
         r"""Forward pass.
 
         Args:
-            inputs: [z, xyz, ijk] or [z, xyz, ijk, w]  if `use_external_weights`
+            inputs (list): [z, xyz, ijk] or [z, xyz, ijk, w]  if `use_external_weights`
 
                 - z (tf.RaggedTensor): Atomic numbers of shape (batch, [N])
                 - xyz (tf.RaggedTensor): Node coordinates of shape (batch, [N], 3)
                 - ijk (tf.RaggedTensor): Angle indices referring to nodes of shape (batch, [M], 3)
                 - w (tf.RaggedTensor): Angle weight tensor of shape (batch, [M], 1)
 
+            mask (list): Boolean mask for inputs. Not used. Defaults to None.
+
         Returns:
             tf.RaggedTensor: Atomic representation of shape `(batch, None, units)` .
         """
         if self.use_external_weights:
-            z, xyz, ijk, w = inputs
+            z, xyz, ijk, w = self.assert_ragged_input_rank(inputs, mask=mask, ragged_rank=1)
             z = self.map_values(tf.cast, z, dtype=ijk.dtype)
             w = self.map_values(tf.cast, w, dtype=self.dtype)
         else:
-            z, xyz, ijk = inputs
+            z, xyz, ijk = self.assert_ragged_input_rank(inputs, mask=mask, ragged_rank=1)
             z = self.map_values(tf.cast, z, dtype=ijk.dtype)
             w1 = self.layer_gather_1([z, ijk], **kwargs)[0]
             w2 = self.layer_gather_2([z, ijk], **kwargs)[0]
@@ -334,9 +338,9 @@ class wACSFAng(GraphBaseLayer):
             w = self.lazy_mult([w1, w2], **kwargs)
             w = self.layer_exp_dims(w, **kwargs)
         xi, xj, xk = self.layer_pos([xyz, ijk])
-        rij = self.layer_dist([xi, xj])
-        rik = self.layer_dist([xi, xk])
-        rjk = self.layer_dist([xj, xk])
+        rij = self.layer_dist([xi, xj], **kwargs)
+        rik = self.layer_dist([xi, xk], **kwargs)
+        rjk = self.layer_dist([xj, xk], **kwargs)
         fij = self.map_values(self._compute_fc, rij, cutoff=self.cutoff)
         fik = self.map_values(self._compute_fc, rik, cutoff=self.cutoff)
         fjk = self.map_values(self._compute_fc, rjk, cutoff=self.cutoff)
@@ -344,10 +348,10 @@ class wACSFAng(GraphBaseLayer):
         gij = self.map_values(self._compute_gaussian_expansion, [rij, zi])
         gik = self.map_values(self._compute_gaussian_expansion, [rik, zi])
         gjk = self.map_values(self._compute_gaussian_expansion, [rjk, zi])
-        vij = self.lazy_sub([xi, xj])
-        vik = self.lazy_sub([xi, xk])
+        vij = self.lazy_sub([xi, xj], **kwargs)
+        vik = self.lazy_sub([xi, xk], **kwargs)
         pow_cos_theta = self.map_values(self._compute_pow_cos_angle_, [vij, vik, rij, rik, zi])
-        rep = self.lazy_mult([pow_cos_theta, gij, gik, gjk, fij, fik, fjk, w])
+        rep = self.lazy_mult([pow_cos_theta, gij, gik, gjk, fij, fik, fjk, w], **kwargs)
         pool_ang = self.pool_sum([xyz, rep, ijk], **kwargs)
         return self.map_values(self._compute_pow_scale, [pool_ang, z])
 
@@ -356,8 +360,8 @@ class wACSFAng(GraphBaseLayer):
         config.update({"eta_mu_lambda_zeta": self.eta_mu_lambda_zeta, "cutoff": self.cutoff,
                        "use_external_weights": self.use_external_weights,
                        "add_eps": self.add_eps,
-                       "param_constraint": self.param_constraint,
-                       "param_regularizer": self.param_regularizer,
-                       "param_initializer": self.param_initializer
+                       "param_constraint": ks.constraints.serialize(self.param_constraint),
+                       "param_regularizer": ks.regularizers.serialize(self.param_regularizer),
+                       "param_initializer": ks.initializers.serialize(self.param_initializer)
                        })
         return config
