@@ -15,26 +15,33 @@ try:
     import rdkit
     import rdkit.Chem
     import rdkit.Chem.AllChem
-
+    import rdkit.Chem.rdDetermineBonds
 
     def rdkit_smile_to_mol(smile: str, sanitize: bool = True, add_hydrogen: bool = True, make_conformers: bool = True,
                            optimize_conformer: bool = True):
+        # Order of parameters is important here.
         try:
             m = rdkit.Chem.MolFromSmiles(smile)
             if sanitize:
                 rdkit.Chem.SanitizeMol(m)
-            if add_hydrogen:
-                m = rdkit.Chem.AddHs(m)  # add H's to the molecule
+
+            m = rdkit.Chem.AddHs(m)
             m.SetProp("_Name", smile.strip())
+
             if make_conformers:
-                rdkit.Chem.RemoveStereochemistry(m)
-                rdkit.Chem.AssignStereochemistry(m)
-                rdkit.Chem.AllChem.EmbedMolecule(m, useRandomCoords=True)
-            if optimize_conformer and make_conformers:
-                rdkit.Chem.AllChem.MMFFOptimizeMolecule(m)
-                rdkit.Chem.AssignAtomChiralTagsFromStructure(m)
-                rdkit.Chem.AssignStereochemistryFrom3D(m)
-                rdkit.Chem.AssignStereochemistry(m)
+                params = rdkit.Chem.AllChem.ETKDGv3()
+                params.useSmallRingTorsions = True
+                # params.useRandomCoords = True
+                success = rdkit.Chem.AllChem.EmbedMolecule(m, params=params)
+                if optimize_conformer:
+                    rdkit.Chem.AllChem.MMFFOptimizeMolecule(m)
+                    rdkit.Chem.AssignAtomChiralTagsFromStructure(m)
+                    rdkit.Chem.AssignStereochemistryFrom3D(m)
+            if not add_hydrogen:
+                m = rdkit.Chem.RemoveHs(m)
+
+            rdkit.Chem.AssignStereochemistry(m)
+
         except:
             m = None
 
@@ -43,9 +50,32 @@ try:
 
         return None
 
+    def rdkit_xyz_to_mol(xyz_string: str, charge = 0):
+        """Convert xyz-string to mol-string.
+
+        The order of atoms in the list should be the same as output. Uses openbabel for conversion.
+
+        Args:
+            xyz_string (str): Convert the xyz string to mol-string
+
+        Returns:
+            str: Mol-string. Generates bond information in addition to coordinates from xyz-string.
+        """
+        try:
+            raw_mol = rdkit.Chem.MolFromXYZBlock(xyz_string)
+            out_mol = rdkit.Chem.Mol(raw_mol)
+            # rdkit.Chem.rdDetermineBonds.DetermineConnectivity(out_mol, charge=charge)
+            rdkit.Chem.rdDetermineBonds.DetermineBonds(out_mol, charge=charge)
+        except:
+            out_mol = None
+        if out_mol is not None:
+            return rdkit.Chem.MolToMolBlock(out_mol)
+        return None
+
 except ImportError:
     module_logger.error("Can not import `RDKit` package for conversion.")
     rdkit_smile_to_mol = None
+    rdkit_xyz_to_mol = None
 
 try:
     # There problems with openbabel if system variable is not set.
@@ -100,7 +130,7 @@ try:
         return None
 
 
-    def openbabel_xyz_to_mol(xyz_string: str, stop_logging: bool = False):
+    def openbabel_xyz_to_mol(xyz_string: str, charge = 0, stop_logging: bool = False):
         """Convert xyz-string to mol-string.
 
         The order of atoms in the list should be the same as output. Uses openbabel for conversion.
@@ -155,11 +185,7 @@ class MolConverter:
             raise ValueError("Conversion was not successful")
 
     @staticmethod
-    def _convert_parallel(conversion_method: Callable,
-                          smile_list: list,
-                          num_workers: int,
-                          *args
-                          ):
+    def _convert_parallel(conversion_method: Callable, smile_list: list, num_workers: int, *args):
         if num_workers is None:
             num_workers = os.cpu_count()
 
@@ -197,17 +223,9 @@ class MolConverter:
         module_logger.warning("Failed conversion for smile '%s'." % smile)
         return None
 
-    def smile_to_mol(self,
-                     smiles_path: str,
-                     sdf_path: str,
-                     external_program: dict = None,
-                     num_workers: int = None,
-                     sanitize: bool = True,
-                     add_hydrogen: bool = True,
-                     make_conformers: bool = True,
-                     optimize_conformer: bool = True,
-                     logger=None,
-                     batch_size: int = 5000):
+    def smile_to_mol(self, smiles_path: str, sdf_path: str, external_program: dict = None, num_workers: int = None,
+                     sanitize: bool = True, add_hydrogen: bool = True, make_conformers: bool = True,
+                     optimize_conformer: bool = True, logger=None, batch_size: int = 5000):
         """Convert a smiles file to SDF structure file.
 
         Args:
@@ -257,6 +275,21 @@ class MolConverter:
         self._check_is_same_length(smiles_list, mol_list)
         return mol_list
 
+    @staticmethod
+    def _single_xyz_to_mol(xyz_string, charge=0):
+        if rdkit_smile_to_mol is not None:
+            mol = rdkit_xyz_to_mol(xyz_string, charge)
+            if mol is not None:
+                return mol
+
+        if openbabel_smile_to_mol is not None:
+            mol = openbabel_xyz_to_mol(xyz_string, charge)
+            if mol is not None:
+                return mol
+
+        module_logger.warning("Failed conversion for xyz '%s'... ." % xyz_string[:20])
+        return None
+
     def xyz_to_mol(self, xyz_path: str, sdf_path: str):
         """Convert xyz info to structure file.
 
@@ -267,13 +300,15 @@ class MolConverter:
         Returns:
 
         """
-        if openbabel_xyz_to_mol is None:
+        if openbabel_xyz_to_mol is None and rdkit_xyz_to_mol is None:
             raise ModuleNotFoundError("Can not convert XYZ to SDF format, missing package `OpenBabel` or `RDkit`.")
+
         xyz_list = read_xyz_file(xyz_path)
         mol_list = []
         for x in xyz_list:
             xyz_str = parse_list_to_xyz_str(x)
-            mol_str = openbabel_xyz_to_mol(xyz_str)
+            # No parallel conversion here, not necessary.
+            mol_str = self._single_xyz_to_mol(xyz_str, charge=0)
             mol_list.append(mol_str)
         self._check_is_same_length(xyz_list, mol_list)
         if sdf_path is not None:
